@@ -92,10 +92,13 @@ class SyncRunner(object):
     self.connection.request_connection(flags)
   def acquire_lock(self):
     lock_name = self.dir + "/.sync_lock"
+    tries = 0
     while True:
       try:
         fd = os.open(lock_name, os.O_RDWR|os.O_CREAT|os.O_EXCL)
-        if fcntl.flock(fd, fcntl.LOCK_EX) < 0:
+        try:
+          fcntl.flock(fd, fcntl.LOCK_EX)
+        except:
           # since we're blocking, this shouldn't happen, in theory
           os.close(fd)
           continue
@@ -107,14 +110,21 @@ class SyncRunner(object):
         except:
           # file vanished, try to lock again
           continue
-        if fcntl.flock(fd, fcntl.LOCK_EX) < 0:
+        try:
+          fcntl.flock(fd, fcntl.LOCK_EX)
+        except:
           # since we're blocking, this shouldn't happen, in theory
           os.close(fd)
           continue
-        buf = os.read(fd)
+        buf = os.read(fd, 256)
         if buf == "":
           # another process might be in the process of locking
           # (opened the file but didn't lock it yet)
+          if tries > 10:
+            # perhaps not, guess we'll take the lock instead
+            break
+          else:
+            tries += 1
           os.close(fd)
           continue
         pid = int(buf)
@@ -124,9 +134,11 @@ class SyncRunner(object):
         os.lseek(fd, 0, 0)
         os.ftruncate(fd, 0)
         break
+    print "lock acquired"
     self.lock_fd = fd
     pid = os.getpid()
     os.write(fd, "%d" % pid)
+    print "locked"
   def release_lock(self):
     os.unlink(self.dir + "/.sync_lock")
     os.close(self.lock_fd)
